@@ -57,6 +57,21 @@ main = defaultMain
          , bgroup "dangerouslyBig" $ benchToBoundedInteger dangerouslyBig
          , bgroup "64"             $ benchToBoundedInteger 64
          ]
+
+       , bgroup "read"
+         [ benchRead "123456789.123456789"
+         , benchRead "12345678900000000000.12345678900000000000000000"
+         , benchRead "12345678900000000000.12345678900000000000000000e1234"
+         ]
+
+       , bgroup "division"
+         [ bench (show n ++ " / " ++ show d) $ nf (uncurry (/)) t
+         | t@(n, d) <-
+           [ (0.4     , 20.0)
+           , (0.4e-100, 0.2e50)
+           ] :: [(Scientific, Scientific)]
+         ]
+
        ]
     where
       pos :: Fractional a => a
